import { LogLevel } from '@genesislcap/foundation-utils';
/**
 * Retrieves the error details from an ErrorStructure object
 * @public
 * @param details - The ErrorStructure object
 * @returns The title and error details concatenated as a string, or default values ('Error: Something went wrong') if not present
 */
export const getErrorDetails = (details) => {
    var _a, _b;
    const title = (_a = details === null || details === void 0 ? void 0 : details.title) !== null && _a !== void 0 ? _a : 'Error';
    const errorDetails = (_b = details === null || details === void 0 ? void 0 : details.errorDetails) !== null && _b !== void 0 ? _b : 'Something went wrong';
    return `${title}: ${errorDetails}`;
};
/**
 * Retrieves the log level from an ErrorStructure object
 * @public
 * @param details - The ErrorStructure object
 * @returns The log level or the default value (LogLevel.Error) if not present
 */
export const getLoglevel = (details) => {
    var _a;
    return (details === null || details === void 0 ? void 0 : details.logLevel) || ((_a = details === null || details === void 0 ? void 0 : details.config) === null || _a === void 0 ? void 0 : _a.logLevel) || LogLevel.Error;
};
/**
 * Get/Create the error container in the DOM
 * @public
 * @param id - The id of the container
 * @param tagName - The tag name to create prefix for the design system provider
 * @returns
 */
export const getErrorContainer = (id, tagName) => {
    const tagPrefix = tagName.split('-')[0];
    let container = document.querySelector(`#${id}`);
    if (!container) {
        container = document.createElement('div');
        container.setAttribute('id', id);
        const dsProvider = document.createElement(`${tagPrefix}-design-system-provider`);
        dsProvider.appendChild(container);
        document.body.appendChild(dsProvider);
    }
    return container;
};
